@@ -4,8 +4,14 @@ from re import sub as re_sub
 
 from falocalrepo_database import FADatabase
 from falocalrepo_database import FADatabaseTable
-from falocalrepo_database.database import Entry
 from falocalrepo_database.database import guess_extension
+from falocalrepo_database.selector import AND
+from falocalrepo_database.selector import LIKE
+from falocalrepo_database.selector import OR
+from falocalrepo_database.selector import Selector
+from falocalrepo_database.types import Entry
+from falocalrepo_database.types import Value
+from filetype.types.image import Jpeg
 from requests import get as req_get
 
 
@@ -97,10 +103,10 @@ def make_submission(db: FADatabase, data: Entry, file: str = None, thumb: str =
             str(data["description"])))))))
     data["userupdate"] = int(data.get("userupdate", 0))
 
-    sub_file, sub_thumb = db.submissions.get_submission_files(data["id"])
-    sub_file = open(file, "rb").read() if file else sub_file
-    sub_thumb = open(thumb, "rb").read() if thumb else sub_thumb
-    assert sub_thumb is None or guess_extension(sub_thumb) == "jpg", "Thumbnail must be in JPEG format"
+    sub_file_db, sub_thumb_db = db.submissions.get_submission_files(data["id"])
+    sub_file = open(file, "rb").read() if file else sub_file_db.read_bytes() if sub_file_db else None
+    sub_thumb = open(thumb, "rb").read() if thumb else sub_thumb_db.read_bytes() if sub_thumb_db else None
+    assert sub_thumb is None or guess_extension(sub_thumb) == Jpeg.EXTENSION, "Thumbnail must be in JPEG format"
 
     db.submissions.save_submission(data, sub_file, sub_thumb)
 
@@ -118,6 +124,11 @@ def make_user(db: FADatabase, data: Entry):
     db.commit()
 
 
+def parameters_to_selector(params: dict[str, list[Value]], keys_and: bool = True, vals_and: bool = False) -> Selector:
+    k_op, v_op = AND if keys_and else OR, AND if vals_and else OR
+    return {k_op: [{v_op: [{LIKE: {k: v} for v in vs}]} for k, vs in params.items()]}
+
+
 def search(table: FADatabaseTable, parameters: dict[str, list[str]], columns: list[str] = None) -> list[Entry]:
     parameters = {k.upper(): vs for k, vs in parameters.items()}
     query: dict[str, list[str]] = {k: vs for k, vs in parameters.items() if k in table.columns}
@@ -128,10 +139,11 @@ def search(table: FADatabaseTable, parameters: dict[str, list[str]], columns: li
         query["USERNAME"] = list(map(lambda u: clean_username(u, "%_"), query["USERNAME"]))
     if "ID" in query:
         query["ID"] = list(map(lambda i: i.lstrip("0") if isinstance(i, str) else i, query["ID"]))
+    if "ANY" in parameters:
+        query[f"({'||'.join(table.columns)})"] = parameters["ANY"]
     return list(table.select(
-        query,
+        parameters_to_selector(query),
         columns=columns,
-        like=True,
         order=parameters.get("order", [table.column_id]),
         limit=int(parameters.get("limit", 0)),
         offset=int(parameters.get("offset", 0))
@@ -145,15 +157,15 @@ def print_items(items: list[Entry]):
         space_term: int = 10000
 
     space_id: int = 10
-    space_user: int = max([len(item["AUTHOR"]) for item in items] + [10])
-    space_date: int = 10
+    space_user: int = max([len(item["AUTHOR"]) for item in items] + [6])
+    space_date: int = 16
 
     print(f"{'ID':^{space_id}} | {'User':^{space_user}} | {'Date':^{space_date}} | Title")
     for item in items:
         print(
             f"{str(item['ID']).zfill(space_id)} | " +
             f"{item['AUTHOR']:<{space_user}} | " +
-            f"{item['DATE']} | " +
+            f"{item['DATE'].replace('T', ' ')} | " +
             item['TITLE'][:(space_term - space_id - space_user - space_date - 10)]
         )
 
