@@ -17,6 +17,8 @@ from falocalrepo_database import FADatabaseCursor
 from falocalrepo_database import FADatabaseTable
 from falocalrepo_database import __version__ as __database_version__
 from falocalrepo_database.database import clean_username
+from falocalrepo_database.exceptions import MultipleConnections
+from falocalrepo_database.selector import Selector
 from falocalrepo_server import __version__ as __server_version__
 from falocalrepo_server import server
 from psutil import AccessDenied
@@ -28,6 +30,7 @@ from .commands import latest_version
 from .commands import make_journal
 from .commands import make_submission
 from .commands import make_user
+from .commands import parameters_to_selector
 from .commands import print_items
 from .commands import print_users
 from .commands import search
@@ -64,7 +67,7 @@ def check_database_version(db: FADatabase, raise_for_error: bool = True):
 def check_database_connections(db: FADatabase):
     if len(db.check_connection(raise_for_error=False)) > 1:
         db.close()
-        raise MultipleInstances(f"Another connection to {db.database_path} was detected")
+        raise MultipleConnections(f"Another connection to {db.database_path} was detected")
 
 
 def raiser(e: Exception) -> Callable:
@@ -239,7 +242,7 @@ def config_files_folder(db: FADatabase, *args: str):
     """
 
     if not args:
-        print(f"files folder: {(ff := db.settings['FILESFOLDER'])} ({db.database_path / ff})")
+        print(f"files folder: {db.settings['FILESFOLDER']} ({db.files_folder.resolve()})")
     elif len(args) == 1:
         print(f"Moving files folder to {args[0]}")
         db.move_files_folder(args[0])
@@ -337,9 +340,9 @@ def download_update(db: FADatabase, *args: str):
         falocalrepo download update tom,jerry
     """
 
+    opts, args = parse_args(args)
     users: list[str] = args[0].split(",") if args and args[0] != "@" else []
     folders: list[str] = args[1].split(",") if args[1:] and args[1] != "@" else []
-    opts, args = parse_args(args)
     download_users_update(db, users, folders, int(opts.get("stop", 1)), opts.get("deactivated", "").lower() == "true")
 
 
@@ -470,11 +473,12 @@ def database_search(table: FADatabaseTable, print_func: Callable, *args: str):
     DESCRIPTION
         Search the {0} entries using metadata fields. Search parameters can
         be passed multiple times to act as OR values. All columns of the {0}
-        table are supported. Parameters can be lowercase. If no parameters are
-        supplied, a list of all {0} will be returned instead. If <json> is
-        set to 'true', the results are printed as a list of objects in JSON format.
-        If <columns> is passed, then the objects printed with the JSON option will
-        only contain those fields.
+        table are supported, the 'any' parameter can be used to match against any
+        column. Parameters can be lowercase. If no parameters are supplied, a list
+        of all {0} will be returned instead. If <json> is set to 'true', the
+        results are printed as a list of objects in JSON format. If <columns> is
+        passed, then the objects printed with the JSON option will only contain
+        those fields.
     """
 
     opts = parameters_multi(args)
@@ -734,12 +738,16 @@ def database_merge_copy(db: FADatabase, merge: bool = True, *args):
     subs_opts: dict[str, list[str]] = {m.group(1): v for k, v in opts.items() if (m := match(r"submissions\.(.+)", k))}
     jrns_opts: dict[str, list[str]] = {m.group(1): v for k, v in opts.items() if (m := match(r"journals\.(.+)", k))}
 
+    usrs_query: Selector = parameters_to_selector(usrs_opts)
+    subs_query: Selector = parameters_to_selector(subs_opts)
+    jrns_query: Selector = parameters_to_selector(jrns_opts)
+
     with FADatabase(args[0]) as db2:
         print(f"{'Merging with database' if merge else 'Copying entries to'} {db2.database_path}...")
         cursors: list[FADatabaseCursor] = []
-        cursors.append((db2 if merge else db).users.select(usrs_opts, like=True)) if usrs_opts else None
-        cursors.append((db2 if merge else db).submissions.select(subs_opts, like=True)) if subs_opts else None
-        cursors.append((db2 if merge else db).journals.select(jrns_opts, like=True)) if jrns_opts else None
+        cursors.append((db2 if merge else db).users.select(usrs_query)) if usrs_opts else None
+        cursors.append((db2 if merge else db).submissions.select(subs_query)) if subs_opts else None
+        cursors.append((db2 if merge else db).journals.select(jrns_query)) if jrns_opts else None
         db.merge(db2, *cursors) if merge else db.copy(db2, *cursors)
         db.commit()
         print("Done")
@@ -965,9 +973,9 @@ def console(comm: str = "", *args: str) -> None:
         database_path = db_path if db_path.name.endswith(".db") else db_path / database_path
 
     db: FADatabase = FADatabase(database_path)
-    check_database_connections(db)
 
     try:
+        check_database_connections(db)
         db.settings.add_history(f"{comm} {' '.join(args)}".strip())
         db.commit()
 
